@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-09-29'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-11-25'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -46,7 +46,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.11 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
+This document describes version 0.12 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-25.
 
 =head1 SYNOPSIS
 
@@ -60,6 +60,10 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -70,12 +74,16 @@ L<Class::Accessor::Array> 0.02
 
 L<Class::InsideOut> 1.13
 
+L<Class::Struct> 0.65
+
 L<Class::Tiny> 1.004
 
 L<Class::XSAccessor> 1.19
 
 L<Class::XSAccessor::Array> 1.19
 
+L<Evo::Class>
+
 L<Mo> 0.40
 
 L<Mojo::Base>
@@ -84,47 +92,75 @@ L<Mojo::Base::XS> 0.07
 
 L<Moo> 2.002004
 
+L<Moops> 0.034
+
+L<Moos> 0.30
+
 L<Moose> 2.1805
 
 L<Mouse> v2.4.5
 
-L<Object::Simple> 3.1703
+L<Object::Simple> 3.17
 
-L<Perl::Examples::Accessors> 0.08
+L<Object::Tiny> 1.08
 
-L<Perl::Examples::Accessors::Array> 0.08
+L<Object::Tiny::RW> 1.07
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.08
+L<Object::Tiny::RW::XS> 0.03
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.08
+L<Object::Tiny::XS> 1.01
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.08
+L<Perl::Examples::Accessors> 0.09
 
-L<Perl::Examples::Accessors::ClassTiny> 0.08
+L<Perl::Examples::Accessors::Array> 0.09
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.08
+L<Perl::Examples::Accessors::ClassAccessor> 0.09
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.08
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.09
 
-L<Perl::Examples::Accessors::Hash> 0.08
+L<Perl::Examples::Accessors::ClassInsideOut> 0.09
 
-L<Perl::Examples::Accessors::Mo> 0.08
+L<Perl::Examples::Accessors::ClassStruct> 0.09
 
-L<Perl::Examples::Accessors::MojoBase> 0.08
+L<Perl::Examples::Accessors::ClassTiny> 0.09
 
-L<Perl::Examples::Accessors::MojoBaseXS> 0.08
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.09
 
-L<Perl::Examples::Accessors::Moo> 0.08
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.09
 
-L<Perl::Examples::Accessors::Moose> 0.08
+L<Perl::Examples::Accessors::EvoClass> 0.09
 
-L<Perl::Examples::Accessors::Mouse> 0.08
+L<Perl::Examples::Accessors::Hash> 0.09
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.08
+L<Perl::Examples::Accessors::Mo> 0.09
 
-L<Perl::Examples::Accessors::Scalar> 0.08
+L<Perl::Examples::Accessors::MojoBase> 0.09
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.08
+L<Perl::Examples::Accessors::MojoBaseXS> 0.09
+
+L<Perl::Examples::Accessors::Moo> 0.09
+
+L<Perl::Examples::Accessors::Moops> 0.09
+
+L<Perl::Examples::Accessors::Moos> 0.09
+
+L<Perl::Examples::Accessors::Moose> 0.09
+
+L<Perl::Examples::Accessors::Mouse> 0.09
+
+L<Perl::Examples::Accessors::ObjectSimple> 0.09
+
+L<Perl::Examples::Accessors::ObjectTiny> 0.09
+
+L<Perl::Examples::Accessors::ObjectTinyRW> 0.09
+
+L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.09
+
+L<Perl::Examples::Accessors::ObjectTinyXS> 0.09
+
+L<Perl::Examples::Accessors::Scalar> 0.09
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.09
 
 L<Simple::Accessor> 1.02
 
@@ -132,27 +168,35 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Class::Tiny (perl_code)
+=item * Class::Struct (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassTiny->new
+ Perl::Examples::Accessors::ClassStruct->new
 
 
 
-=item * Object::Simple (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ObjectSimple->new
+ Perl::Examples::Accessors::Moo->new
 
 
 
-=item * Class::Accessor (perl_code)
+=item * Object::Tiny::RW::XS (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassAccessor->new
+ Perl::Examples::Accessors::ObjectTinyRWXS->new
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassInsideOut->new
 
 
 
@@ -164,6 +208,62 @@ Code template:
 
 
 
+=item * Moose (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::MojoBase->new
+
+
+
+=item * no generator (scalar-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * Evo::Class (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::EvoClass->new
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessor->new
+
+
+
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::SimpleAccessor->new
+
+
+
 =item * Mojo::Base::XS (perl_code)
 
 Code template:
@@ -172,11 +272,51 @@ Code template:
 
 
 
-=item * Moose (perl_code)
+=item * Object::Tiny::XS (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Moose->new
+ Perl::Examples::Accessors::ObjectTinyXS->new
+
+
+
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ObjectSimple->new
+
+
+
+=item * Moos (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moos->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
+=item * Class::Tiny (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassTiny->new
+
+
+
+=item * Moops (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moops->new
 
 
 
@@ -196,38 +336,6 @@ Code template:
 
 
 
-=item * no generator (scalar-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassInsideOut->new
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
-
-
-
-=item * Mo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mo->new
-
-
-
 =item * Class::XSAccessor::Array (perl_code)
 
 Code template:
@@ -236,19 +344,11 @@ Code template:
 
 
 
-=item * Mojo::Base (perl_code)
+=item * Object::Tiny::RW (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::MojoBase->new
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::SimpleAccessor->new
+ Perl::Examples::Accessors::ObjectTinyRW->new
 
 
 
@@ -260,11 +360,11 @@ Code template:
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Object::Tiny (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassXSAccessor->new
+ Perl::Examples::Accessors::ObjectTiny->new
 
 
 
@@ -272,7 +372,7 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
@@ -280,29 +380,33 @@ Benchmark with default options (C<< bencher -m Accessors::Construction >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Class::InsideOut            |    188000 |    5.32   |      1     | 1.6e-09 |      22 |
- | Simple::Accessor            |    330000 |    3.1    |      1.7   | 6.1e-09 |      24 |
- | Class::Tiny                 |    370000 |    2.7    |      2     | 3.3e-09 |      20 |
- | Moose                       |    520000 |    1.9    |      2.8   | 3.3e-09 |      20 |
- | Mo                          |    770000 |    1.3    |      4.1   | 2.1e-09 |      20 |
- | Moo                         |   1019000 |    0.9818 |      5.416 | 1.1e-11 |      20 |
- | Class::Accessor             |   1100000 |    0.92   |      5.8   | 1.7e-09 |      20 |
- | Mouse                       |   1400000 |    0.7    |      7.6   |   1e-09 |      20 |
- | no generator (array-based)  |   1700000 |    0.58   |      9.1   | 8.3e-10 |      20 |
- | Object::Simple              |   2100000 |    0.48   |     11     | 8.3e-10 |      20 |
- | no generator (hash-based)   |   2152000 |    0.4646 |     11.45  | 1.1e-11 |      20 |
- | Mojo::Base                  |   2200000 |    0.455  |     11.7   | 2.1e-10 |      20 |
- | Class::Accessor::Array      |   2360000 |    0.4238 |     12.55  | 1.1e-11 |      20 |
- | no generator (scalar-based) |   2400000 |    0.416  |     12.8   | 2.1e-10 |      20 |
- | Class::XSAccessor           |   3200000 |    0.31   |     17     | 4.5e-10 |      20 |
- | Mojo::Base::XS              |   3200000 |    0.31   |     17     | 3.9e-10 |      23 |
- | Class::XSAccessor::Array    |   3500000 |    0.29   |     18     | 8.7e-10 |      20 |
+ | Moos                        |    141000 |  7.12     |    1       | 3.3e-09 |      20 |
+ | Class::InsideOut            |    330000 |  3        |    2.4     | 3.8e-09 |      24 |
+ | Simple::Accessor            |    450000 |  2.22     |    3.2     | 6.8e-10 |      30 |
+ | Class::Tiny                 |    645176 |  1.54996  |    4.59165 |   0     |      22 |
+ | Evo::Class                  |    814000 |  1.23     |    5.79    | 4.2e-10 |      20 |
+ | Moose                       |    825000 |  1.21     |    5.87    | 3.8e-10 |      24 |
+ | Mo                          |   1070000 |  0.932    |    7.64    | 4.2e-10 |      20 |
+ | Class::Struct               |   1212000 |  0.8251   |    8.625   | 1.2e-11 |      27 |
+ | Moops                       |   1300000 |  0.76     |    9.4     | 1.6e-09 |      21 |
+ | Moo                         |   1320000 |  0.757    |    9.4     | 4.2e-10 |      20 |
+ | Class::Accessor             |   1546430 |  0.646649 |   11.0058  |   0     |      20 |
+ | Mouse                       |   1703000 |  0.5872   |   12.12    | 3.4e-11 |      20 |
+ | no generator (array-based)  |   2100000 |  0.48     |   15       | 5.6e-10 |      25 |
+ | no generator (hash-based)   |   2550410 |  0.392094 |   18.151   |   0     |      20 |
+ | Mojo::Base                  |   2700000 |  0.371    |   19.2     | 2.1e-10 |      20 |
+ | Object::Simple              |   2700000 |  0.37     |   19.2     |   2e-10 |      22 |
+ | Object::Tiny::RW            |   2771870 |  0.360768 |   19.7271  |   0     |      20 |
+ | Object::Tiny                |   2820000 |  0.355    |   20.1     | 1.8e-10 |      26 |
+ | no generator (scalar-based) |   2934000 |  0.3409   |   20.88    | 1.2e-11 |      20 |
+ | Class::Accessor::Array      |   2950000 |  0.339    |   21       |   2e-10 |      22 |
+ | Object::Tiny::RW::XS        |   4300000 |  0.23     |   30       | 4.2e-10 |      20 |
+ | Class::XSAccessor           |   4400000 |  0.23     |   31       | 2.8e-10 |      25 |
+ | Mojo::Base::XS              |   4400000 |  0.23     |   31       | 4.2e-10 |      20 |
+ | Class::XSAccessor::Array    |   4382620 |  0.228174 |   31.1906  |   0     |      20 |
+ | Object::Tiny::XS            |   4388670 |  0.22786  |   31.2336  |   0     |      20 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
-=head1 DESCRIPTION
-
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Accessors>.
