@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-09-29'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-11-25'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.11 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
+This document describes version 0.12 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-25.
 
 =head1 SYNOPSIS
 
@@ -45,6 +45,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -55,12 +59,16 @@ L<Class::Accessor::Array> 0.02
 
 L<Class::InsideOut> 1.13
 
+L<Class::Struct> 0.65
+
 L<Class::Tiny> 1.004
 
 L<Class::XSAccessor> 1.19
 
 L<Class::XSAccessor::Array> 1.19
 
+L<Evo::Class>
+
 L<Mo> 0.40
 
 L<Mojo::Base>
@@ -69,11 +77,23 @@ L<Mojo::Base::XS> 0.07
 
 L<Moo> 2.002004
 
+L<Moops> 0.034
+
+L<Moos> 0.30
+
 L<Moose> 2.1805
 
 L<Mouse> v2.4.5
 
-L<Object::Simple> 3.1703
+L<Object::Simple> 3.17
+
+L<Object::Tiny> 1.08
+
+L<Object::Tiny::RW> 1.07
+
+L<Object::Tiny::RW::XS> 0.03
+
+L<Object::Tiny::XS> 1.01
 
 L<Simple::Accessor> 1.02
 
@@ -81,21 +101,27 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Class::Tiny (perl_code)
+=item * Class::Struct (perl_code)
 
-L<Class::Tiny>
+L<Class::Struct>
 
 
 
-=item * Object::Simple (perl_code)
+=item * Moo (perl_code)
 
-L<Object::Simple>
+L<Moo>
 
 
 
-=item * Class::Accessor (perl_code)
+=item * Object::Tiny::RW::XS (perl_code)
 
-L<Class::Accessor>
+L<Object::Tiny::RW::XS>
+
+
+
+=item * Class::InsideOut (perl_code)
+
+L<Class::InsideOut>
 
 
 
@@ -105,15 +131,85 @@ L<Mouse>
 
 
 
+=item * Moose (perl_code)
+
+L<Moose>
+
+
+
+=item * Mojo::Base (perl_code)
+
+L<Mojo::Base>
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Evo::Class (perl_code)
+
+L<Evo::Class>
+
+
+
+=item * Class::Accessor (perl_code)
+
+L<Class::Accessor>
+
+
+
+=item * Mo (perl_code)
+
+L<Mo>
+
+
+
+=item * Simple::Accessor (perl_code)
+
+L<Simple::Accessor>
+
+
+
 =item * Mojo::Base::XS (perl_code)
 
 L<Mojo::Base::XS>
 
 
 
-=item * Moose (perl_code)
+=item * Object::Tiny::XS (perl_code)
 
-L<Moose>
+L<Object::Tiny::XS>
+
+
+
+=item * Object::Simple (perl_code)
+
+L<Object::Simple>
+
+
+
+=item * Moos (perl_code)
+
+L<Moos>
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+L<Class::XSAccessor>
+
+
+
+=item * Class::Tiny (perl_code)
+
+L<Class::Tiny>
+
+
+
+=item * Moops (perl_code)
+
+L<Moops>
 
 
 
@@ -127,43 +223,15 @@ L<Class::Accessor::Array>
 
 
 
-=item *  (perl_code)
-
-
-
-=item * Class::InsideOut (perl_code)
-
-L<Class::InsideOut>
-
-
-
-=item * Moo (perl_code)
-
-L<Moo>
-
-
-
-=item * Mo (perl_code)
-
-L<Mo>
-
-
-
 =item * Class::XSAccessor::Array (perl_code)
 
 L<Class::XSAccessor::Array>
 
 
 
-=item * Mojo::Base (perl_code)
+=item * Object::Tiny::RW (perl_code)
 
-L<Mojo::Base>
-
-
-
-=item * Simple::Accessor (perl_code)
-
-L<Simple::Accessor>
+L<Object::Tiny::RW>
 
 
 
@@ -171,9 +239,9 @@ L<Simple::Accessor>
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Object::Tiny (perl_code)
 
-L<Class::XSAccessor>
+L<Object::Tiny>
 
 
 
@@ -181,7 +249,7 @@ L<Class::XSAccessor>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
 
@@ -189,27 +257,31 @@ Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
  +--------------------------+-----------+------------------------+------------+-----------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
- | Moose                    |     170   |                  164.4 |        1   |   0.00044 |      20 |
- | Mouse                    |      26   |                   20.4 |        6.6 |   3e-05   |      20 |
- | Moo                      |      20   |                   14.4 |        8.5 | 6.9e-05   |      21 |
- | Class::InsideOut         |      17   |                   11.4 |       10   | 7.4e-05   |      20 |
- | Mojo::Base               |      17   |                   11.4 |       10   | 8.3e-05   |      20 |
- | Class::Tiny              |      15   |                    9.4 |       11   | 6.5e-05   |      20 |
- | Object::Simple           |      13   |                    7.4 |       13   | 6.1e-05   |      20 |
- | Class::XSAccessor::Array |      12   |                    6.4 |       14   | 1.5e-05   |      20 |
- | Class::Accessor          |      12   |                    6.4 |       14   | 3.8e-05   |      21 |
- | Class::XSAccessor        |      12   |                    6.4 |       14   | 7.4e-05   |      21 |
- | Mojo::Base::XS           |       8.9 |                    3.3 |       19   | 4.7e-05   |      20 |
- | Class::Accessor::Array   |       7.7 |                    2.1 |       22   | 3.7e-05   |      21 |
- | Simple::Accessor         |       7.5 |                    1.9 |       23   | 2.1e-05   |      21 |
- | Mo                       |       7.4 |                    1.8 |       23   | 6.6e-05   |      20 |
- | perl -e1 (baseline)      |       5.6 |                    0   |       30   | 1.1e-05   |      20 |
+ | Moose                    |     150   |                  144.3 |        1   |   0.00036 |      20 |
+ | Moops                    |      66   |                   60.3 |        2.2 | 6.9e-05   |      20 |
+ | Evo::Class               |      36   |                   30.3 |        4.1 |   0.0001  |      21 |
+ | Mouse                    |      24   |                   18.3 |        6.1 | 3.5e-05   |      20 |
+ | Moos                     |      20   |                   14.3 |        7.3 | 6.3e-05   |      20 |
+ | Moo                      |      20   |                   14.3 |        7.6 | 4.4e-05   |      20 |
+ | Class::InsideOut         |      16   |                   10.3 |        9.2 | 2.8e-05   |      21 |
+ | Mojo::Base               |      16   |                   10.3 |        9.4 | 3.1e-05   |      20 |
+ | Class::Tiny              |      14   |                    8.3 |       10   | 3.8e-05   |      20 |
+ | Class::Struct            |      13   |                    7.3 |       11   | 3.2e-05   |      21 |
+ | Class::XSAccessor::Array |      13   |                    7.3 |       12   | 4.3e-05   |      21 |
+ | Object::Tiny::RW::XS     |      13   |                    7.3 |       12   | 3.8e-05   |      20 |
+ | Object::Simple           |      13   |                    7.3 |       12   | 1.5e-05   |      21 |
+ | Object::Tiny::XS         |      13   |                    7.3 |       12   | 4.6e-05   |      21 |
+ | Class::Accessor          |      12   |                    6.3 |       12   | 3.4e-05   |      20 |
+ | Class::XSAccessor        |      12   |                    6.3 |       12   |   2e-05   |      20 |
+ | Mojo::Base::XS           |       9.5 |                    3.8 |       16   | 5.3e-05   |      20 |
+ | Simple::Accessor         |       8.6 |                    2.9 |       17   | 1.7e-05   |      20 |
+ | Class::Accessor::Array   |       7.9 |                    2.2 |       19   | 3.2e-05   |      20 |
+ | Mo                       |       7.9 |                    2.2 |       19   | 1.1e-05   |      20 |
+ | Object::Tiny             |       6.9 |                    1.2 |       21   | 3.5e-05   |      23 |
+ | Object::Tiny::RW         |       6.8 |                    1.1 |       22   | 2.1e-05   |      20 |
+ | perl -e1 (baseline)      |       5.7 |                    0   |       26   | 1.7e-05   |      20 |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
 
-=head1 DESCRIPTION
-
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Accessors>.
